/** \file Variable.h
\brief Define the environment variable
\author alpha_one_x86
\licence GPL3, see the file COPYING */

#ifndef VARIABLE_H
#define VARIABLE_H


//Un-comment this next line to put ultracopier plugin in debug mode
#ifndef ULTRACOPIER_NODEBUG
#define ULTRACOPIER_PLUGIN_DEBUG
#endif

#define ULTRACOPIER_VERSION_ULTIMATE

#endif // VARIABLE_H



